#include <avr/io.h>
#include "T6963C.h"
#include "uart.h"

void int2hex(unsigned char zahl)
/*
 * Author:       Jochen Rurlaender
 * Version:      1.0
 * Datum  :      14.08.2004
 * Beschreibung:
 * Wandelt eine integer Zahl in eine Hex-Zahl um und gibt diese auf
 * der seriellen Schnittstelle aus
 */
{     
	unsigned char high;
	high = (zahl >> 4);
	USART_Transmit((high ) + (((high)  > 9) ? 0x37 : 0x30));	 
	USART_Transmit((zahl & 0xF) + (((zahl & 0xF) > 9) ? 0x37 : 0x30));	
}

void int2bin(unsigned char data)
{
	char bin[8] = {'0','0','0','0','0','0','0','0'};
	
	if ((data & 0x01) == 0x01) bin[0] = '1';
	if ((data & 0x02) == 0x02) bin[1] = '1';
	if ((data & 0x04) == 0x04) bin[2] = '1';
	if ((data & 0x08) == 0x08) bin[3] = '1';
	if ((data & 0x10) == 0x10) bin[4] = '1';
	if ((data & 0x20) == 0x20) bin[5] = '1';
	if ((data & 0x40) == 0x40) bin[6] = '1';
	if ((data & 0x80) == 0x80) bin[7] = '1';
	
	signed char i;
	for(i=7; i>=0; i--)
	{
		USART_Transmit(bin[i]);
	}

}


void check_bussy(void)
{
	unsigned char by;

	DATA_IN(); //DatenPort auf Eingang zum lesen
	CMD_ON();    //Kommando Modus

	 do         //Schleife Status Bits checken
	 {
		CE_ON();
		RD_ON();
		by=READ_DATA(); //Status lesen
		RD_OFF();
		CE_OFF();
		int2hex(by);
		int2bin(by);
		USART_New_Line();
	}while((by&3) != 3); //Solange STA0 oder STA1 = 0
}


void write_command(unsigned char command)
{
	check_bussy();
	
	DATA_OUT();	//DatenPort auf Ausgang zum schreiben
	CMD_ON();	//Kommando Modus aktivieren
	WRITE_DATA(command);	//Kommando am Port anlegen
	
	CE_ON();
	WR_ON();
	WR_OFF();
	CE_OFF();
}

void write_data(unsigned char data)
{
	check_bussy(); //StatusBits STA0,1 checken
	
	DATA_OUT(); //DatenPort auf Ausgang zum schreiben
	DATA_ON();     //DisplayDaten schreiben vorbereiten
	WRITE_DATA(data); //Daten auf den Port
	
	CE_ON();
	WR_ON();
	WR_OFF();
	CE_OFF();
}

void write_command_1data(unsigned char command, unsigned char data1)
{
	write_data(data1);
	write_command(command);	
}

void write_command_2data(unsigned char command, unsigned char data1, unsigned char data2)
{
	write_data(data1);
	write_data(data2);
	write_command(command);	
}

void init_glcd(void)
{
	RS_ON();
	RS_OFF();

	write_command(0x80);
	write_command_2data(0x42,0x00,0x00);	
	write_command_2data(0x43,0x10,0x00);	
	write_command_2data(0x40,0x00,0x10);
	write_command_2data(0x41,0x10,0x00);
	
	write_command_2data(0x24,0x00,0x00);	
	write_command_1data(0xC0,0x55);
	write_command_1data(0xC0,0xAA);
	
	write_command_2data(0x24,0x00,0x10);
	write_command_1data(0xC0,0x34);
	write_command_1data(0xC0,0x4F);

	write_command(0x9C);
	
}

